"""Constants and type aliases for textual-wtf."""

from __future__ import annotations

from typing import Literal

LabelStyle = Literal["above", "beside", "placeholder"]
HelpStyle = Literal["below", "tooltip"]
